# Systematic Trading Package

This is a simple systematic trading package.


## Packaging and distribution

Generating distribution archives

```bash
python3 -m pip install --upgrade build
python3 -m build
```